# IANA Language Tags for Python #

[![Pypi package](https://badge.fury.io/py/language_tags.png)](http://badge.fury.io/py/language_tags)
[![Build Status](https://travis-ci.org/OnroerendErfgoed/language-tags.png?branch=master)](https://travis-ci.org/OnroerendErfgoed/language-tags)
[![Coverage Status](https://coveralls.io/repos/OnroerendErfgoed/language-tags/badge.png)](https://coveralls.io/r/OnroerendErfgoed/language-tags)
[![Documentation Status](https://readthedocs.org/projects/language-tags/badge/?version=latest)](https://readthedocs.org/projects/language-tags/?badge=latest)

Based on [BCP 47](http://tools.ietf.org/html/bcp47) ([RFC 5646](http://tools.ietf.org/html/rfc5646)) and the latest [IANA language subtag registry](http://www.iana.org/assignments/language-subtag-registry).

This project will be updated as the standards change.

## JSON data ##

See the [language-subtag-registry](https://github.com/mattcg/language-subtag-registry) project for the underlying JSON data.

## Javascript version ##

This project is a Python version of the [language-tags](https://github.com/mattcg/language-tags) Javascript project.
